#[attrA]
#[make_qobject]
#[attrB]
pub mod my_object {}
